#!/bin/sh

LOGGING_LEVEL=WARNING
LOG_FILE_LOCATION=$RPA_HOME/logs/RPA_MA.log
DCI_IP_ADDRESS=

#!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
#!!!!!!!!!!!!!! DO NOT EDIT ANYTHING BELOW THIS POINT !!!!!!!!!!!!
#!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

# ----------------------------------------------------------------
# | Define some additional helper evironment variables           |
# ----------------------------------------------------------------
# export DEBUG_RPA_LAUNCHER=1
export SEPARATOR=:
export HYADES_PLUGINS=$AC_HOME/plugins

# ----------------------------------------------------------------
# | Configure the launch parameters                              |
# ----------------------------------------------------------------
export HPATH=$AC_HOME/lib
export TPATH=$ARM_HOME/lib

CONFIG_PATH="-Djlog.propertyFileDir=${ARM_HOME}/config/ "
ROOTDIR="-Darm.plugin.rootdir=${ARM_HOME}/ "
ARMCONTROLLER="-Dtmtp.arm.controller=com.ibm.tivoli.transperf.arm.impl.TMTPArmControllerFactory "
MSID="-Darm.plugin.msid=11111111111111111111111111111111 "
if [ -z $DCI_IP_ADDRESS ]; then
	export RUNTIME_PROPERTIES=${CONFIG_PATH}${ROOTDIR}${ARMCONTROLLER}${MSID}
else
	IPADDRESS="-Dcom.ibm.rpa.runtime.ip=${DCI_IP_ADDRESS} "
	export RUNTIME_PROPERTIES=${CONFIG_PATH}${ROOTDIR}${ARMCONTROLLER}${MSID}${IPADDRESS}
fi

# ----------------------------------------------------------------
# | Define the logging parameters                                |
# ----------------------------------------------------------------
LOGGING_CLASS="-Djava.util.logging.config.class=com.ibm.rpa.runtime.LogConfig "
LOG_FILEHANDLER="-Dlog.fileHandler=java.util.logging.FileHandler "
LOG_FORMATTER="-Dlog.formatter=org.eclipse.hyades.logging.java.XmlFormatter "
LOG_PATTERN="-Dlog.pattern=${LOG_FILE_LOCATION} "
LOG_RPA_SEVERITY="-Dlog.rpa.severity=${LOGGING_LEVEL} "
export LOGGING_PROPERTIES=${LOGGING_CLASS}${LOG_FILEHANDLER}${LOG_FORMATTER}${LOG_PATTERN}${LOG_RPA_SEVERITY}

# ---------------------------------------------------------------------------
# | Generate the classpath. Because the date is tagged to most of the JARS, |
# | we must dynamically locate the appropriate jar. If, for some reason,    |
# | there are multiple jars with the same name but different timestamp (ie  |
# | com.ibm.rpa.core_20070505.jar and com.ibm.rpa.core_20080505.jar), this  |
# | script will add the most recent jar to the classpath.                   |
# ---------------------------------------------------------------------------
for file in ${RPA_HOME}/com.ibm.rpa.core* ; do
	export RPA_LOGGING_JAR=${file}
done

JARPATH=
# Get the Hyades Execution directory
for dir in ${HYADES_PLUGINS}/org.eclipse.hyades.execution*/ ; do
	export HYADES_EXECUTION_DIR=${dir}
done

# Construct the partial classpath with the hyades execution jars
for jar in hexcore.jar hexl.jar hexr.jar ; do 
	export JARPATH=${JARPATH}${HYADES_EXECUTION_DIR}${jar}${SEPARATOR}
done

# Construct the partial classpath with the ICU jars
for jar in ${HYADES_PLUGINS}/com.ibm.icu_*.jar ; do
	ICU_JAR=${jar}
done
export JARPATH=${JARPATH}${ICU_JAR}${SEPARATOR}

# Get the Hyades Logging directory
for dir in ${HYADES_PLUGINS}/org.eclipse.hyades.logging.core*/ ; do
	export HYADES_LOGGING_DIR=${dir}
done

# Construct the partial classpath with the hyades logging jars
for jar in hl14.jar hlcommons.jar hlcore.jar hllog4j.jar ; do
	export JARPATH=${JARPATH}${HYADES_LOGGING_DIR}${jar}${SEPARATOR}
done

# Get the TPTP Logging Events directory
for dir in ${HYADES_PLUGINS}/org.eclipse.tptp.platform.logging.events*/ ; do
	export TPTP_LOGGING_EVENTS_DIR=${dir}
done

# Construct the partial classpath with the TPTP logging events jars
for jar in hlcbe101.jar tlcbe101.jar tlcore.jar ; do
	export JARPATH=${JARPATH}${TPTP_LOGGING_EVENTS_DIR}${jar}${SEPARATOR}
done

# Add the EMF Common jar to the classpath
for jar in ${HYADES_PLUGINS}/org.eclipse.emf.common_*.jar ; do
	EMF_COMMON=${jar}
done
export JARPATH=${JARPATH}${EMF_COMMON}${SEPARATOR}

# Add the EMF Ecore jar to the classpath
for jar in ${HYADES_PLUGINS}/org.eclipse.emf.ecore_*.jar ; do
	EMF_ECORE=${jar}
done
export JARPATH=${JARPATH}${EMF_ECORE}${SEPARATOR}

# Add the RPA core plugin to the classpath
for jar in ${RPA_HOME}/com.ibm.rpa.runtime_* ; do
	RPA_RUNTIME=${jar}
done	
export JARPATH=${JARPATH}${RPA_RUNTIME}${SEPARATOR}

# Get the Apache Logging directory
for dir in ${HYADES_PLUGINS}/org.apache.commons_logging*/ ; do
	APACHE_LOGGING_DIR=${dir}
done

# Complete the classpath
for jar in ${APACHE_LOGGING_DIR}lib/commons-logging* ; do
	APACHE_LOGGING_JAR=${jar}
done
export JARPATH=${JARPATH}${APACHE_LOGGING_JAR}
